@@ -1,7 +1,7 @@
-use super::*;
 use crate::sequence::helper::*;
 use std::convert::From;
 use std::convert::TryFrom;
+use super::*;
 
 /// ```rust
 /// use letter_sequence::sequence::builder;
@@ -17,7 +17,7 @@ use std::convert::TryFrom;
 /// assert_eq!( seq.to_string(), "AA" );
 /// ```
 ///
-/// This time with .max_chars() set, and lowercase
+/// This time with .max_render_capacity() set, and lowercase
 /// ```rust
 /// use letter_sequence::sequence::builder;
 /// use std::convert::TryFrom;
@@ -25,12 +25,12 @@ use std::convert::TryFrom;
 /// let mut seq = builder::SequenceBuilder::try_from('y')
 ///   .unwrap()
 /// 	.lower()
-/// 	.max_chars(1)
+/// 	.max_render_capacity(1)
 /// 	.build()
 /// 	.unwrap();
 /// assert_eq!( seq.next().unwrap().to_string(), "z"  );
 /// assert_eq!( seq.to_string(),                 "z"  );
-/// // Without .max_chars(1) this would reutrn "aa"
+/// // Without .max_render_capacity(1) this would reutrn "aa"
 /// assert_eq!( seq.next(),                      None );
 /// ```
 ///
@@ -46,58 +46,60 @@ use std::convert::TryFrom;
 /// assert_eq!( seq.next().unwrap().to_string(), "103"  );
 /// assert_eq!( seq.to_string(),                 "103"  );
 /// ```
+#[derive(Debug, Default)]
 pub struct SequenceBuilder {
 	start: u64,
-	display: RenderDisplay,
-	bound: Option<u8>,
-}
-
-impl Default for SequenceBuilder {
-	fn default() -> Self {
-		Self { start: 0, bound: None, display: RenderDisplay::Upper }
-	}
+	renderer: SeqRendererBuilder,
+	length: Option<u8>,
 }
 
 impl SequenceBuilder {
-	/// Creates a new default Sequence starting at `start` (0-base)
+	/// Creates a new Sequence starting at `start` (0-base)
 	/// ```
 	/// use letter_sequence::sequence::builder;
-	/// let seq = builder::SequenceBuilder::new(2).build().unwrap();
+	///
+	/// let seq = builder::SequenceBuilder::new(2).upper().build().unwrap();
 	/// assert_eq!( seq.to_string(), "C" );
+	///
+	/// let seq = builder::SequenceBuilder::new(5).build().unwrap();
+	/// assert_eq!( seq.to_string(), "5" );
 	/// ```
 	pub fn new(start: u64) -> Self {
 		Self { start, ..Default::default() }
 	}
-
-	pub fn new_from_string(start: &str) -> () {
-		todo!("Process from a string, create sequence that represents state")
+	/// Limits the chacters in rendered output, incrementing past limit generates
+	/// error. default: unlimited
+	pub fn max_render_capacity(mut self, chars: u8) -> Self {
+		self.renderer = self.renderer.capacity(chars);
+		self
 	}
-
-	/// Set a limit on the sequence based on the chacters in rendered output, default: unlimited
-	pub fn max_chars(mut self, chars: u8) -> Self {
-		self.bound = Some(chars);
+	/// Limits the minimum width of the rendered output, this only works on
+	/// Numeric which effectively zero-pads the output.
+	pub fn length(mut self, chars: u8) -> Self {
+		self.length = Some(chars);
 		self
 	}
 	/// Render the sequence in lowercase
 	pub fn lower(mut self) -> Self {
-		self.display = RenderDisplay::Lower;
+		self.renderer = self.renderer.lower();
 		self
 	}
 	/// Render the sequence in uppercase, default
 	pub fn upper(mut self) -> Self {
-		self.display = RenderDisplay::Upper;
+		self.renderer = self.renderer.upper();
 		self
 	}
 	/// Render the sequence in digits
 	pub fn numeric(mut self) -> Self {
-		self.display = RenderDisplay::Numeric;
+		self.renderer = self.renderer.numeric();
 		self
 	}
+
 	pub fn build(self) -> Result<Sequence, SequenceError> {
-		let renderer = SeqRenderer {
-			display: self.display,
-			bound: self.bound,
-			.. Default::default()
+		let renderer = self.renderer.build()?;
+		match (renderer.display(), self.length) {
+			(RenderDisplay::Upper | RenderDisplay::Lower, Some(_)) => return Err(SequenceError::PaddingAlpha),
+			_ => ()
 		};
 		let mut seq = Sequence {
 			inner: 0,
@@ -115,10 +117,36 @@ impl From<u64> for SequenceBuilder {
 	}
 }
 
+/// ```rust
+/// use letter_sequence::sequence::builder::SequenceBuilder;
+/// use std::convert::TryFrom;
+///	assert_eq!(
+///		SequenceBuilder::try_from("00001")
+///			.unwrap()
+///			.build()
+///			.unwrap()
+///			.to_string(),
+///		"1"
+///	);
+///	assert_eq!(
+///		SequenceBuilder::try_from("00001")
+///			.unwrap()
+///			.upper()
+///			.build()
+///			.unwrap()
+///			.to_string(),
+///		"B"
+///	);
+/// ```
 impl TryFrom<&str> for SequenceBuilder {
 	type Error = SequenceError;
 	fn try_from(value: &str) -> Result<Self, Self::Error> {
-		Ok(Self::new(string_to_int(value)?))
+		let first_char = value.chars().next().unwrap();
+		match renderer::RenderDisplay::try_from(first_char)? {
+			renderer::RenderDisplay::Numeric => Ok( Self::new(value.parse::<u64>().unwrap()).numeric() ),
+			renderer::RenderDisplay::Upper => Ok( Self::new(string_to_int(&value)?).upper() ),
+			renderer::RenderDisplay::Lower => Ok( Self::new(string_to_int(&value)?).lower() )
+		}
 	}
 }
 
@@ -133,14 +161,18 @@ impl TryFrom<char> for SequenceBuilder {
 mod test {
 	use super::*;
 
-	/// Test violations of the bounds system, ensure we return an error
+	/// Test violations of the max_render_capacity system, ensure we return an error
 	/// Test that we can increment past respective .max_numeric and .max_alpha
 	#[test]
-	fn bounds() {
+	fn max_render_capacity() {
 		// Test link between max_alpha(chars) and the OutOfRange
 		for limit in 1..10 {
 			let max = crate::sequence::renderer::max_alpha(limit);
-			let mut seq = SequenceBuilder::new(max).max_chars(limit).build().unwrap();
+			println!("MAX {}, LIMIT {}", max, limit);
+			let mut seq = SequenceBuilder::new(max).upper().max_render_capacity(limit);
+			println!("seqbuilder {:?}", seq);
+			let mut seq = seq.build().unwrap();
+			println!("seq {:?}", seq);
 			let render_as = "Z".repeat(limit as usize);
 			assert_eq!( seq.to_string(), render_as );
 			assert_eq!(
@@ -153,7 +185,7 @@ mod test {
 		// Test max_numeric(chars) + 1 throws OutOfRange
 		for limit in 1..10 {
 			let max = crate::sequence::renderer::max_numeric(limit);
-			let mut seq = SequenceBuilder::new(max).numeric().max_chars(limit).build().unwrap();
+			let mut seq = SequenceBuilder::new(max).numeric().max_render_capacity(limit).build().unwrap();
 			let render_as = "9".repeat(limit as usize);
 			assert_eq!( seq.to_string(), render_as, "Render {} as {}", max, render_as );
 			assert_eq!(
