@@ -41,7 +41,7 @@ pub fn int_to_string(i: u64) -> Result<String, SequenceError> {
 pub fn int_to_char(i: u32) -> Result<char, SequenceError> {
 	const ASCII_A_OFFSET: u32 = 'A' as u32;
 	if i > LETTERS as u32 {
-		return Err(SequenceError::OutOfRange)
+		return Err(SequenceError::NotAsciiCharacter)
 	}
 	let letter = std::char::from_u32(i + ASCII_A_OFFSET)
 		.unwrap();
@@ -62,7 +62,7 @@ pub fn char_to_int(c: char) -> Result<u8, SequenceError> {
 		Ok(c.to_ascii_uppercase() as u8 - 'A' as u8)
 	}
 	else {
-		Err(SequenceError::InvalidCharacter)
+		Err(SequenceError::InvalidCharacter(c))
 	}
 }
 
@@ -71,15 +71,15 @@ pub fn char_to_int(c: char) -> Result<u8, SequenceError> {
 /// use letter_sequence::sequence::helper;
 /// assert_eq!( helper::string_to_int("A").unwrap(), 0  );
 /// assert_eq!( helper::string_to_int("Z").unwrap(), 25 );
-/// assert_eq!( helper::string_to_int("AZ").unwrap(), 26 );
+/// assert_eq!( helper::string_to_int("AA").unwrap(), 26 );
 /// use letter_sequence::SequenceError;
-/// assert_eq!( helper::string_to_int(",").unwrap_err(), SequenceError::InvalidCharacter );
+/// assert_eq!( helper::string_to_int(",").unwrap_err(), SequenceError::InvalidCharacter(',') );
 /// ```
 pub fn string_to_int(s: &str) -> Result<u64, SequenceError> {
 	let mut max: u64 = 0;
 	for (i,val) in s.chars().rev().enumerate() {
 		let ord = char_to_int(val)? as u64;
-		max += (1+ord).pow(1 + i as u32);
+		max += (1+ord) * 26u64.pow(i as u32);
 	}
 	Ok(max - 1)
 }
@@ -97,7 +97,7 @@ mod test{
 			}
 			assert_eq!(
 				int_to_char('Z' as u32 + 1).unwrap_err(),
-				SequenceError::OutOfRange
+				SequenceError::NotAsciiCharacter
 			)
 		}
 	}
